@@ -1,4 +1,4 @@
-# $Id: Directory.pm 42169 2014-09-08 13:09:57Z anton $
+# $Id: Directory.pm 42176 2014-09-09 09:51:55Z anton $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/pwdmodifier/libpwdmodifier/lib/UvT/PwdModifier/Directory.pm $
 
 use strict;
@@ -432,7 +432,7 @@ sub toggleAccountState {
 
 	if ($on) {
 		my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst) = localtime(time);
-		$year += 1900; $mday += 1 ; $mon += 1;
+		$year += 1900;  $mon += 1;
 		my $content = sprintf("$year-%02d-%02d %02d:%02d $by",$mon, $mday, $hour, $min);
 		$entry->replace($attrib, $content);
 	} else {
