@@ -1,4 +1,4 @@
-# $Id: SQL.pm 40714 2013-12-11 12:07:05Z anton $
+# $Id: SQL.pm 41112 2014-03-13 16:02:26Z anton $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/pwdmodifier/libpwdmodifier/lib/UvT/PwdModifier/SQL.pm $
 #
 # Er wordt door deze app geschreven naar adb123, die wordt eens in het uur ofzo gelezen
@@ -218,22 +218,6 @@ sub getQAMModified {
 	return $time;
 }
 
-
-sub clearExpirationStatus {
-	my ($anr) = @_;
-	$self->query_do('clearExpirationStatus', $anr);
-}
-
-sub newExpirationStatus {
-	my ($anr, $time, $newstatus) = @_;
-	$self->query_do('newExpirationStatus', @_);
-}
-
-sub changeExpirationStatus {
-	my ($anr, $time, $newstatus) = @_;
-	$self->query_do('changeExpirationStatus', $time, $newstatus, $anr);
-}
-
 sub setMail {
 	my ($anr, $mail) = @_;
 	$self->query_do('deleteMail', $anr);
